function filt = designFilter(filter, len, d)
%
%		FILTER=designFilter(TYPE,LEN,D)
%	Returns Fourier transformation of filter defined in TYPE of length LEN truncated to the 
%	frequencies fraction D.
%		TYPE [string] = 'ram-lak' for ramp filter without windowing,
%										'shepp-logan' for ramp filter with sinc window,
%										'hamming' for ramp filter with Hamming window.
%		LEN [1 x n] 	= length of the filter (always even).
%		D [1 x 1]			= number 0...1 fraction of frequencies used for filtering.


order=round(len/2)*2;
filt = 2*( 0:(order/2) )./order;
w = 2*pi*(0:size(filt,2)-1)/order;   % frequency axis up to Nyquist 

switch filter
case 'ram-lak'
   % Do nothing
case 'shepp-logan'
   % be careful not to divide by 0:
   filt(2:end) = filt(2:end) .* (sin(w(2:end)/(2*d))./(w(2:end)/(2*d)));
case 'hamming'  
   filt(2:end) = filt(2:end) .* (.54 + .46 * cos(w(2:end)/d));
end
filt(w>pi*d) = 0;                      % Crop the frequency response
filt = [filt' ; filt(end-1:-1:2)'];    % Symmetry of the filter